XBCellTitleSwitch class

Inheritance
Implementers

Constructors

XBCellTitleSwitch({required String title, required bool isOn, Color? activeColor, TextStyle? titleStyle, double? titleRightPadding, double? maxTitleWidth, int? titleMaxLines, TextOverflow? titleOverflow, double? contentHeight, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, VoidCallback? onTap, BorderRadiusGeometry contentBorderRadius = BorderRadius.zero, Color? backgroundColor, Widget? backgroundWidget, bool isShowArrow = false, Color? arrowColor, double? arrowLeftPadding, double? arrowSize, bool isNeedBtn = false, Key? key})
const

Properties

activeColor Color?
final
arrowColor Color?
finalinherited
arrowLeftPadding double?
finalinherited
arrowSize double?
finalinherited
backgroundColor Color?
finalinherited
backgroundWidget Widget?
finalinherited
contentBorderRadius BorderRadiusGeometry
finalinherited
contentHeight double?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isNeedBtn bool
finalinherited
isOn bool
final
isShowArrow bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
finalinherited
maxTitleWidth double?
finalinherited
onTap VoidCallback?
finalinherited
padding EdgeInsetsGeometry?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
finalinherited
titleMaxLines int?
finalinherited
titleOverflow TextOverflow?
finalinherited
titleRightPadding double?
finalinherited
titleStyle TextStyle?
finalinherited

Methods

arrowWidget() Widget
inherited
bottomContent() Widget
inherited
bottomWidget() Widget
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
content() Widget
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
leftWidget() Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rightWidget() Widget
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited