XBFloatMenu class

Inheritance

Constructors

XBFloatMenu({Key? key, required Widget child, required int itemCount, required XBFloatMenuItemBuilder itemBuilder, required Widget separatorBuilder(int index), required double width, bool tapContentHide = true, Color? bgColor, int type = 0, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, Color? shadowColor})
const

Properties

bgColor Color?
finalinherited
child Widget
finalinherited
contentWidth double
no setteroverride
crossAxisAlignment CrossAxisAlignment
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder XBFloatMenuItemBuilder
final
itemCount int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minGapToBorder double
内容到屏幕边缘的最小距离
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separatorBuilder Widget Function(int index)
final
shadowColor Color?
final
tapContentHide bool
finalinherited
type int
finalinherited
width double
final

Methods

arrow(Offset position, double arrowHeight, double arrowStart, double arrowWidth) Widget
inherited
buildContent(Offset position, double contentLeft, bool isAbove, Function hide) Widget
inherited
buildContentWithoutArrow(Offset position, double contentLeft, bool isAbove, Function hide) Widget
override
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<XBFloatWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited