XBLoadingTask class

Constructors

XBLoadingTask(String name, {bool topLeftEnable = true, bool topCenterEnable = false, bool topRightEnable = false, bool contentEnable = false, String? msg, Widget? widget})

Properties

contentEnable bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
msg String?
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topCenterEnable bool
getter/setter pair
topLeftEnable bool
getter/setter pair
topRightEnable bool
getter/setter pair
widget Widget?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited