XBPageVM<T> class

Inheritance
Mixed-in types
Implementers

Constructors

XBPageVM({required BuildContext context})

Properties

context BuildContext
finalinherited
disposed bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isFinishedPushAnimation bool
no setter
isShowLoadingWidget bool
no setter
isTop bool
页面在栈顶
getter/setter pair
loadingMsg String?
getter/setter pair
loadingWidgetFadeKey GlobalKey<XBFadeWidgetState>
no setter
needShowLoadingWidget bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldKey GlobalKey<ScaffoldState>
final
state XBWidgetState<XBVM>
getter/setter pairinherited
widget → T
no setterinherited
widgetSize Size
getter/setter pairinherited

Methods

addEnsureAfterPushAnimationTask(void fun()) → dynamic
添加动画完成后的任务
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
back<O extends Object?>([O? result]) → void
closeDrawer() → dynamic
closeEndDrawer() → dynamic
didChangeDependencies() → void
override
didCreated() → void
已经完成创建
override
didFinishedPushAnimation() → dynamic
didPop() → void
Called when the current route has been popped off.
override
didPopNext() → void
Called when the top route has been popped off, and the current route shows up.
override
didPush() → void
Called when the current route has been pushed.
override
didPushNext() → void
Called when a new route has been pushed, and the current route is no longer visible.
override
didUpdateWidget(covariant T oldWidget) → void
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
hideLoading() → dynamic
listen<E>(dynamic onData(E)) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → dynamic
通知刷新
override
notifyListeners() → void
Call all the registered listeners.
inherited
onWillPop() → dynamic
-------------------- function -------------------- 即将pop
openDrawer() → dynamic
openEndDrawer() → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
showLoading({String? msg}) → dynamic
toString() String
A string representation of this object.
inherited
widgetDidBuilt() → void
页面已经build完成
inherited
widgetSizeDidChanged() → void
inherited
willDispose() → void
即将销毁
willHide() → void
即将隐藏,从展示状态变成被覆盖状态
willShow() → void
即将展示,从被覆盖状态变成展示状态

Operators

operator ==(Object other) bool
The equality operator.
inherited