XBSectionIndexPath class

Constructors

XBSectionIndexPath(int section, int index)

Properties

hashCode int
The hash code for this object.
no setteroverride
index int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
section int
getter/setter pair

Methods

compareTo(XBSectionIndexPath other) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override