XBTip class

Inheritance

Constructors

XBTip({Key? key, required Widget child, required String tip, int type = 0, bool tapContentHide = true, TextStyle? tipStyle, Color? bgColor, double paddingH = 10, double maxWidth = 280})
const

Properties

bgColor Color?
finalinherited
child Widget
finalinherited
contentWidth double
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxWidth double
final
minGapToBorder double
内容到屏幕边缘的最小距离
finalinherited
paddingH double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tapContentHide bool
finalinherited
tip String
final
tipStyle TextStyle?
final
type int
finalinherited

Methods

arrow(Offset position, double arrowHeight, double arrowStart, double arrowWidth) Widget
inherited
buildContent(Offset position, double contentLeft, bool isAbove, Function hide) Widget
inherited
buildContentWithoutArrow(Offset position, double contentLeft, bool isAbove, Function hide) Widget
override
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<XBFloatWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textSize() Size
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited